@@ -9,17 +9,15 @@ package Comics::Plugin::EEK;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "0.02";
+our $VERSION = "1.01";
 
 our $name    = "EEK!";
 our $url     = "http://www.gocomics.com/eek/";
 our $pattern =
-	  qr{ <img \s+
-	       alt="(?<alt>[^"]+)" \s+
-	       class="strip" \s+
-	       src="(?<url>http://assets.amuniversal.com/
-	           (?<image>[0-9a-f]+))" \s+
-	       width="\d+" \s*
+	  qr{ <meta \s+
+	       property="og:image" \s+
+	       content="(?<url>http://assets.amuniversal.com/
+	           (?<image>[0-9a-f]+))" \s*
 	       />
             }x;
 
